@@ -225,6 +225,9 @@ get_mod(<<"max-items-exceeded">>,
 get_mod(<<"x">>, <<"jabber:x:conference">>) -> xep0249;
 get_mod(<<"jid">>, <<"urn:xmpp:mam:1">>) -> xep0313;
 get_mod(<<"never">>, <<"urn:xmpp:mam:0">>) -> xep0313;
+get_mod(<<"tie-break">>,
+	<<"urn:xmpp:jingle:errors:1">>) ->
+    xep0166;
 get_mod(<<"item">>,
 	<<"http://jabber.org/protocol/pubsub">>) ->
     xep0060;
@@ -271,6 +274,10 @@ get_mod(<<"INTL">>, <<"vcard-temp">>) -> xep0054;
 get_mod(<<"item">>,
 	<<"http://jabber.org/protocol/muc#admin">>) ->
     xep0045;
+get_mod(<<"gone">>, <<"urn:xmpp:jingle:1">>) -> xep0166;
+get_mod(<<"range">>,
+	<<"urn:xmpp:jingle:apps:file-transfer:5">>) ->
+    xep0234;
 get_mod(<<"error">>, <<"jabber:component:accept">>) ->
     rfc6120;
 get_mod(<<"password">>, <<"jabber:iq:auth">>) ->
@@ -278,6 +285,10 @@ get_mod(<<"password">>, <<"jabber:iq:auth">>) ->
 get_mod(<<"TZ">>, <<"vcard-temp">>) -> xep0054;
 get_mod(<<"request">>, <<"urn:xmpp:http:upload">>) ->
     xep0363;
+get_mod(<<"timeout">>, <<"urn:xmpp:jingle:1">>) ->
+    xep0166;
+get_mod(<<"content">>, <<"urn:xmpp:jingle:1">>) ->
+    xep0166;
 get_mod(<<"nick">>, <<"storage:bookmarks">>) -> xep0048;
 get_mod(<<"iq">>, <<"jabber:component:accept">>) ->
     rfc6120;
@@ -289,6 +300,9 @@ get_mod(<<"query">>,
     xep0045;
 get_mod(<<"thumbnail">>, <<"urn:xmpp:thumbs:1">>) ->
     xep0264;
+get_mod(<<"security-required">>,
+	<<"urn:xmpp:jingle:errors:1">>) ->
+    xep0166;
 get_mod(<<"url">>, <<"jabber:iq:register">>) -> xep0077;
 get_mod(<<"GIVEN">>, <<"vcard-temp">>) -> xep0054;
 get_mod(<<"TYPE">>, <<"vcard-temp">>) -> xep0054;
@@ -302,12 +316,18 @@ get_mod(<<"x">>,
     xep0045;
 get_mod(<<"media">>, <<"urn:xmpp:media-element">>) ->
     xep0221;
+get_mod(<<"out-of-order">>,
+	<<"urn:xmpp:jingle:errors:1">>) ->
+    xep0166;
 get_mod(<<"KEYWORD">>, <<"vcard-temp">>) -> xep0054;
 get_mod(<<"result">>, <<"urn:xmpp:mam:tmp">>) ->
     xep0313;
 get_mod(<<"active">>, <<"urn:xmpp:csi:0">>) -> xep0352;
 get_mod(<<"slot">>, <<"urn:xmpp:http:upload">>) ->
     xep0363;
+get_mod(<<"data">>,
+	<<"http://jabber.org/protocol/ibb">>) ->
+    xep0047;
 get_mod(<<"query">>, <<"jabber:iq:roster">>) -> rfc6121;
 get_mod(<<"digest">>, <<"jabber:iq:auth">>) -> xep0078;
 get_mod(<<"NUMBER">>, <<"vcard-temp">>) -> xep0054;
@@ -346,6 +366,8 @@ get_mod(<<"start">>, <<"urn:xmpp:mam:tmp">>) -> xep0313;
 get_mod(<<"received">>, <<"urn:xmpp:carbons:2">>) ->
     xep0280;
 get_mod(<<"x">>, <<"jabber:x:event">>) -> xep0022;
+get_mod(<<"general-error">>, <<"urn:xmpp:jingle:1">>) ->
+    xep0166;
 get_mod(<<"nick">>, <<"jabber:iq:register">>) ->
     xep0077;
 get_mod(<<"internal-server-error">>,
@@ -389,6 +411,9 @@ get_mod(<<"improper-addressing">>,
 	<<"urn:ietf:params:xml:ns:xmpp-streams">>) ->
     rfc6120;
 get_mod(<<"r">>, <<"urn:xmpp:sm:3">>) -> xep0198;
+get_mod(<<"unsupported-info">>,
+	<<"urn:xmpp:jingle:errors:1">>) ->
+    xep0166;
 get_mod(<<"query">>, <<"jabber:iq:version">>) ->
     xep0092;
 get_mod(<<"archived">>, <<"urn:xmpp:mam:tmp">>) ->
@@ -420,6 +445,7 @@ get_mod(<<"compressed">>,
 get_mod(<<"instructions">>, <<"jabber:x:data">>) ->
     xep0004;
 get_mod(<<"join">>, <<"urn:xmpp:mix:0">>) -> xep0369;
+get_mod(<<"idle">>, <<"urn:xmpp:idle:1">>) -> xep0319;
 get_mod(<<"retract">>,
 	<<"http://jabber.org/protocol/pubsub#event">>) ->
     xep0060;
@@ -442,6 +468,7 @@ get_mod(<<"city">>, <<"jabber:iq:register">>) ->
     xep0077;
 get_mod(<<"query">>, <<"urn:xmpp:delegation:1">>) ->
     xep0355;
+get_mod(<<"hash">>, <<"urn:xmpp:hashes:2">>) -> xep0300;
 get_mod(<<"invalid-options">>,
 	<<"http://jabber.org/protocol/pubsub#errors">>) ->
     xep0060;
@@ -478,6 +505,9 @@ get_mod(<<"enable">>, <<"urn:xmpp:sm:2">>) -> xep0198;
 get_mod(<<"no-permanent-storage">>,
 	<<"urn:xmpp:hints">>) ->
     xep0334;
+get_mod(<<"unsupported-applications">>,
+	<<"urn:xmpp:jingle:1">>) ->
+    xep0166;
 get_mod(<<"text">>, <<"urn:xmpp:reporting:0">>) ->
     xep0377;
 get_mod(<<"credentials-expired">>,
@@ -492,6 +522,12 @@ get_mod(<<"processing-failed">>,
 get_mod(<<"address">>,
 	<<"http://jabber.org/protocol/address">>) ->
     xep0033;
+get_mod(<<"unsupported-transports">>,
+	<<"urn:xmpp:jingle:1">>) ->
+    xep0166;
+get_mod(<<"file-not-available">>,
+	<<"urn:xmpp:jingle:apps:file-transfer:errors:0">>) ->
+    xep0234;
 get_mod(<<"c">>,
 	<<"http://jabber.org/protocol/caps">>) ->
     xep0115;
@@ -525,15 +561,23 @@ get_mod(<<"no-storage">>, <<"urn:xmpp:hints">>) ->
 get_mod(<<"stream:stream">>, <<"jabber:client">>) ->
     rfc6120;
 get_mod(<<"data">>, <<"urn:xmpp:bob">>) -> xep0231;
+get_mod(<<"success">>, <<"urn:xmpp:jingle:1">>) ->
+    xep0166;
 get_mod(<<"method">>,
 	<<"http://jabber.org/protocol/compress">>) ->
     xep0138;
 get_mod(<<"x">>, <<"jabber:x:data">>) -> xep0004;
+get_mod(<<"transport">>,
+	<<"urn:xmpp:jingle:transports:s5b:1">>) ->
+    xep0260;
 get_mod(<<"CONFIDENTIAL">>, <<"vcard-temp">>) ->
     xep0054;
 get_mod(<<"subscribe">>,
 	<<"http://jabber.org/protocol/pubsub">>) ->
     xep0060;
+get_mod(<<"media-type">>,
+	<<"urn:xmpp:jingle:apps:file-transfer:5">>) ->
+    xep0234;
 get_mod(<<"stream:features">>, <<"jabber:client">>) ->
     rfc6120;
 get_mod(<<"fin">>, <<"urn:xmpp:mam:1">>) -> xep0313;
@@ -550,6 +594,17 @@ get_mod(<<"always">>, <<"urn:xmpp:mam:1">>) -> xep0313;
 get_mod(<<"errors">>,
 	<<"urn:xmpp:features:dialback">>) ->
     xep0220;
+get_mod(<<"media-error">>, <<"urn:xmpp:jingle:1">>) ->
+    xep0166;
+get_mod(<<"name">>,
+	<<"urn:xmpp:jingle:apps:file-transfer:5">>) ->
+    xep0234;
+get_mod(<<"description">>,
+	<<"urn:xmpp:jingle:apps:file-transfer:5">>) ->
+    xep0234;
+get_mod(<<"checksum">>,
+	<<"urn:xmpp:jingle:apps:file-transfer:5">>) ->
+    xep0234;
 get_mod(<<"host-gone">>,
 	<<"urn:ietf:params:xml:ns:xmpp-streams">>) ->
     rfc6120;
@@ -561,6 +616,9 @@ get_mod(<<"handshake">>,
 get_mod(<<"not-subscribed">>,
 	<<"http://jabber.org/protocol/pubsub#errors">>) ->
     xep0060;
+get_mod(<<"size">>,
+	<<"urn:xmpp:jingle:apps:file-transfer:5">>) ->
+    xep0234;
 get_mod(<<"query">>,
 	<<"http://jabber.org/protocol/stats">>) ->
     xep0039;
@@ -600,6 +658,9 @@ get_mod(<<"redirect">>,
 get_mod(<<"a">>, <<"urn:xmpp:sm:3">>) -> xep0198;
 get_mod(<<"info">>, <<"urn:xmpp:avatar:metadata">>) ->
     xep0084;
+get_mod(<<"date">>,
+	<<"urn:xmpp:jingle:apps:file-transfer:5">>) ->
+    xep0234;
 get_mod(<<"not-allowed">>,
 	<<"urn:ietf:params:xml:ns:xmpp-stanzas">>) ->
     rfc6120;
@@ -616,10 +677,15 @@ get_mod(<<"put">>, <<"urn:xmpp:http:upload:0">>) ->
 get_mod(<<"file-too-large">>,
 	<<"eu:siacs:conversations:http:upload">>) ->
     xep0363;
+get_mod(<<"received">>,
+	<<"urn:xmpp:jingle:apps:file-transfer:5">>) ->
+    xep0234;
 get_mod(<<"JABBERID">>, <<"vcard-temp">>) -> xep0054;
 get_mod(<<"subscription">>,
 	<<"http://jabber.org/protocol/pubsub#event">>) ->
     xep0060;
+get_mod(<<"decline">>, <<"urn:xmpp:jingle:1">>) ->
+    xep0166;
 get_mod(<<"key">>, <<"jabber:iq:register">>) -> xep0077;
 get_mod(<<"unsupported">>,
 	<<"http://jabber.org/protocol/pubsub#errors">>) ->
@@ -647,6 +713,12 @@ get_mod(<<"x">>, <<"jabber:x:expire">>) -> xep0023;
 get_mod(<<"max-file-size">>,
 	<<"urn:xmpp:http:upload">>) ->
     xep0363;
+get_mod(<<"unknown-session">>,
+	<<"urn:xmpp:jingle:errors:1">>) ->
+    xep0166;
+get_mod(<<"candidate-used">>,
+	<<"urn:xmpp:jingle:transports:s5b:1">>) ->
+    xep0260;
 get_mod(<<"not-well-formed">>,
 	<<"urn:ietf:params:xml:ns:xmpp-streams">>) ->
     rfc6120;
@@ -655,6 +727,9 @@ get_mod(<<"content-type">>,
     xep0363;
 get_mod(<<"perm">>, <<"urn:xmpp:privilege:1">>) ->
     xep0356;
+get_mod(<<"close">>,
+	<<"http://jabber.org/protocol/ibb">>) ->
+    xep0047;
 get_mod(<<"internal-server-error">>,
 	<<"urn:ietf:params:xml:ns:xmpp-stanzas">>) ->
     rfc6120;
@@ -669,62 +744,32 @@ get_mod(<<"never">>, <<"urn:xmpp:mam:1">>) -> xep0313;
 get_mod(<<"metadata">>,
 	<<"urn:xmpp:avatar:metadata">>) ->
     xep0084;
-get_mod(<<"bad-format">>,
-	<<"urn:ietf:params:xml:ns:xmpp-streams">>) ->
-    rfc6120;
-get_mod(<<"STREET">>, <<"vcard-temp">>) -> xep0054;
-get_mod(<<"status">>,
-	<<"http://jabber.org/protocol/muc#user">>) ->
-    xep0045;
 get_mod(<<"password">>,
 	<<"http://jabber.org/protocol/muc#owner">>) ->
     xep0045;
-get_mod(<<"error">>, <<"jabber:server">>) -> rfc6120;
 get_mod(<<"method">>,
 	<<"http://jabber.org/features/compress">>) ->
     xep0138;
-get_mod(<<"VIDEO">>, <<"vcard-temp">>) -> xep0054;
-get_mod(<<"redirect">>,
-	<<"http://jabber.org/protocol/pubsub#event">>) ->
-    xep0060;
 get_mod(<<"invalid-jid">>,
 	<<"http://jabber.org/protocol/pubsub#errors">>) ->
     xep0060;
-get_mod(<<"destroy">>,
-	<<"http://jabber.org/protocol/muc#user">>) ->
-    xep0045;
-get_mod(<<"id">>, <<"jabber:x:event">>) -> xep0022;
 get_mod(<<"iq">>, <<"jabber:client">>) -> rfc6120;
-get_mod(<<"not-acceptable">>,
-	<<"urn:ietf:params:xml:ns:xmpp-stanzas">>) ->
-    rfc6120;
-get_mod(<<"SUFFIX">>, <<"vcard-temp">>) -> xep0054;
 get_mod(<<"LOCALITY">>, <<"vcard-temp">>) -> xep0054;
-get_mod(<<"redirect">>,
-	<<"http://jabber.org/protocol/pubsub">>) ->
-    xep0060;
 get_mod(<<"inactive">>,
 	<<"http://jabber.org/protocol/chatstates">>) ->
     xep0085;
-get_mod(<<"subject">>, <<"jabber:server">>) -> rfc6120;
-get_mod(<<"bad-namespace-prefix">>,
-	<<"urn:ietf:params:xml:ns:xmpp-streams">>) ->
-    rfc6120;
-get_mod(<<"EXTADD">>, <<"vcard-temp">>) -> xep0054;
-get_mod(<<"affiliation">>,
-	<<"http://jabber.org/protocol/pubsub#owner">>) ->
-    xep0060;
 get_mod(<<"affiliations">>,
 	<<"http://jabber.org/protocol/pubsub#owner">>) ->
     xep0060;
 get_mod(<<"first">>,
 	<<"http://jabber.org/protocol/rsm">>) ->
     xep0059;
-get_mod(<<"fin">>, <<"urn:xmpp:mam:0">>) -> xep0313;
-get_mod(<<"enabled">>, <<"urn:xmpp:sm:2">>) -> xep0198;
 get_mod(<<"get">>,
 	<<"eu:siacs:conversations:http:upload">>) ->
     xep0363;
+get_mod(<<"failed-application">>,
+	<<"urn:xmpp:jingle:1">>) ->
+    xep0166;
 get_mod(<<"priority">>, <<"jabber:server">>) -> rfc6120;
 get_mod(<<"redirect">>,
 	<<"urn:ietf:params:xml:ns:xmpp-stanzas">>) ->
@@ -732,92 +777,47 @@ get_mod(<<"redirect">>,
 get_mod(<<"encryption-required">>,
 	<<"urn:ietf:params:xml:ns:xmpp-sasl">>) ->
     rfc6120;
-get_mod(<<"TITLE">>, <<"vcard-temp">>) -> xep0054;
-get_mod(<<"too-many-subscriptions">>,
-	<<"http://jabber.org/protocol/pubsub#errors">>) ->
-    xep0060;
-get_mod(<<"item">>,
-	<<"http://jabber.org/protocol/muc#owner">>) ->
-    xep0045;
-get_mod(<<"always">>, <<"urn:xmpp:mam:0">>) -> xep0313;
 get_mod(<<"stanza-id">>, <<"urn:xmpp:sid:0">>) ->
     xep0359;
 get_mod(<<"complete">>,
 	<<"http://jabber.org/protocol/commands">>) ->
     xep0050;
-get_mod(<<"file-too-large">>,
-	<<"urn:xmpp:http:upload:0">>) ->
-    xep0363;
 get_mod(<<"enable">>, <<"urn:xmpp:push:0">>) -> xep0357;
 get_mod(<<"time">>, <<"urn:xmpp:time">>) -> xep0202;
-get_mod(<<"conflict">>,
-	<<"urn:ietf:params:xml:ns:xmpp-streams">>) ->
-    rfc6120;
 get_mod(<<"invalid-namespace">>,
 	<<"urn:ietf:params:xml:ns:xmpp-streams">>) ->
     rfc6120;
-get_mod(<<"X400">>, <<"vcard-temp">>) -> xep0054;
 get_mod(<<"PREFIX">>, <<"vcard-temp">>) -> xep0054;
-get_mod(<<"affiliation">>,
-	<<"http://jabber.org/protocol/pubsub">>) ->
-    xep0060;
 get_mod(<<"affiliations">>,
 	<<"http://jabber.org/protocol/pubsub">>) ->
     xep0060;
-get_mod(<<"data">>, <<"urn:xmpp:avatar:data">>) ->
-    xep0084;
-get_mod(<<"item">>,
-	<<"http://jabber.org/protocol/disco#items">>) ->
-    xep0030;
+get_mod(<<"desc">>,
+	<<"urn:xmpp:jingle:apps:file-transfer:5">>) ->
+    xep0234;
 get_mod(<<"aborted">>,
 	<<"urn:ietf:params:xml:ns:xmpp-sasl">>) ->
     rfc6120;
 get_mod(<<"address">>, <<"jabber:iq:register">>) ->
     xep0077;
-get_mod(<<"VOICE">>, <<"vcard-temp">>) -> xep0054;
 get_mod(<<"LOGO">>, <<"vcard-temp">>) -> xep0054;
-get_mod(<<"vCard">>, <<"vcard-temp">>) -> xep0054;
 get_mod(<<"retract">>,
 	<<"http://jabber.org/protocol/pubsub">>) ->
     xep0060;
-get_mod(<<"gone">>,
-	<<"http://jabber.org/protocol/chatstates">>) ->
-    xep0085;
 get_mod(<<"destroy">>,
 	<<"http://jabber.org/protocol/muc#owner">>) ->
     xep0045;
-get_mod(<<"query">>,
-	<<"http://jabber.org/protocol/muc#owner">>) ->
-    xep0045;
-get_mod(<<"os">>, <<"jabber:iq:version">>) -> xep0092;
-get_mod(<<"feature">>,
-	<<"http://jabber.org/protocol/disco#info">>) ->
-    xep0030;
 get_mod(<<"compress">>,
 	<<"http://jabber.org/protocol/compress">>) ->
     xep0138;
-get_mod(<<"ORGNAME">>, <<"vcard-temp">>) -> xep0054;
-get_mod(<<"NOTE">>, <<"vcard-temp">>) -> xep0054;
-get_mod(<<"REV">>, <<"vcard-temp">>) -> xep0054;
 get_mod(<<"ADR">>, <<"vcard-temp">>) -> xep0054;
 get_mod(<<"continue">>,
 	<<"http://jabber.org/protocol/muc#user">>) ->
     xep0045;
 get_mod(<<"subscription">>, <<"urn:xmpp:mucsub:0">>) ->
     p1_mucsub;
-get_mod(<<"query">>, <<"urn:xmpp:mam:1">>) -> xep0313;
 get_mod(<<"item">>, <<"jabber:iq:search">>) -> xep0055;
 get_mod(<<"stream:stream">>, <<"jabber:server">>) ->
     rfc6120;
-get_mod(<<"remote-server-not-found">>,
-	<<"urn:ietf:params:xml:ns:xmpp-stanzas">>) ->
-    rfc6120;
-get_mod(<<"invalid-mechanism">>,
-	<<"urn:ietf:params:xml:ns:xmpp-sasl">>) ->
-    rfc6120;
-get_mod(<<"starttls">>,
-	<<"urn:ietf:params:xml:ns:xmpp-tls">>) ->
-    rfc6120;
 get_mod(<<"proceed">>,
 	<<"urn:ietf:params:xml:ns:xmpp-tls">>) ->
     rfc6120;
@@ -826,31 +826,18 @@ get_mod(<<"instructions">>, <<"jabber:iq:register">>) ->
 get_mod(<<"undefined-condition">>,
 	<<"urn:ietf:params:xml:ns:xmpp-streams">>) ->
     rfc6120;
-get_mod(<<"unsupported-feature">>,
-	<<"urn:ietf:params:xml:ns:xmpp-streams">>) ->
-    rfc6120;
 get_mod(<<"DESC">>, <<"vcard-temp">>) -> xep0054;
-get_mod(<<"request">>, <<"urn:xmpp:receipts">>) ->
-    xep0184;
-get_mod(<<"url">>, <<"storage:bookmarks">>) -> xep0048;
-get_mod(<<"unexpected-request">>,
-	<<"urn:ietf:params:xml:ns:xmpp-stanzas">>) ->
-    rfc6120;
-get_mod(<<"zip">>, <<"jabber:iq:register">>) -> xep0077;
-get_mod(<<"delete">>,
-	<<"http://jabber.org/protocol/pubsub#owner">>) ->
-    xep0060;
 get_mod(<<"subscriptions">>, <<"urn:xmpp:mucsub:0">>) ->
     p1_mucsub;
 get_mod(<<"resumed">>, <<"urn:xmpp:sm:2">>) -> xep0198;
-get_mod(<<"a">>, <<"urn:xmpp:sm:2">>) -> xep0198;
-get_mod(<<"dialback">>,
-	<<"urn:xmpp:features:dialback">>) ->
-    xep0220;
-get_mod(<<"put">>, <<"urn:xmpp:http:upload">>) ->
-    xep0363;
 get_mod(<<"slot">>, <<"urn:xmpp:http:upload:0">>) ->
     xep0363;
+get_mod(<<"open">>,
+	<<"http://jabber.org/protocol/ibb">>) ->
+    xep0047;
+get_mod(<<"connectivity-error">>,
+	<<"urn:xmpp:jingle:1">>) ->
+    xep0166;
 get_mod(<<"query">>, <<"jabber:iq:privacy">>) ->
     xep0016;
 get_mod(<<"forbidden">>,
@@ -867,6 +854,9 @@ get_mod(<<"stream:features">>, <<"jabber:server">>) ->
 get_mod(<<"request">>,
 	<<"eu:siacs:conversations:http:upload">>) ->
     xep0363;
+get_mod(<<"file">>,
+	<<"urn:xmpp:jingle:apps:file-transfer:5">>) ->
+    xep0234;
 get_mod(<<"query">>, <<"jabber:iq:auth">>) -> xep0078;
 get_mod(<<"username">>, <<"jabber:iq:register">>) ->
     xep0077;
@@ -891,6 +881,9 @@ get_mod(<<"count">>,
 	<<"http://jabber.org/protocol/rsm">>) ->
     xep0059;
 get_mod(<<"ip">>, <<"urn:xmpp:sic:0">>) -> xep0279;
+get_mod(<<"file-too-large">>,
+	<<"urn:xmpp:jingle:apps:file-transfer:errors:0">>) ->
+    xep0234;
 get_mod(<<"active">>, <<"jabber:iq:privacy">>) ->
     xep0016;
 get_mod(<<"text">>,
@@ -918,6 +911,8 @@ get_mod(<<"address">>, <<"urn:xmpp:sic:1">>) -> xep0279;
 get_mod(<<"max-file-size">>,
 	<<"urn:xmpp:http:upload:0">>) ->
     xep0363;
+get_mod(<<"cancel">>, <<"urn:xmpp:jingle:1">>) ->
+    xep0166;
 get_mod(<<"error">>,
 	<<"http://jabber.org/protocol/stats">>) ->
     xep0039;
@@ -937,6 +932,11 @@ get_mod(<<"disable">>, <<"urn:xmpp:push:0">>) ->
     xep0357;
 get_mod(<<"delegated">>, <<"urn:xmpp:delegation:1">>) ->
     xep0355;
+get_mod(<<"hash-used">>, <<"urn:xmpp:hashes:2">>) ->
+    xep0300;
+get_mod(<<"security-error">>,
+	<<"urn:xmpp:jingle:1">>) ->
+    xep0166;
 get_mod(<<"presence">>,
 	<<"jabber:component:accept">>) ->
     rfc6120;
@@ -977,6 +977,9 @@ get_mod(<<"sm">>, <<"urn:xmpp:sm:3">>) -> xep0198;
 get_mod(<<"fetch">>,
 	<<"http://jabber.org/protocol/offline">>) ->
     xep0013;
+get_mod(<<"failed-transport">>,
+	<<"urn:xmpp:jingle:1">>) ->
+    xep0166;
 get_mod(<<"abuse">>, <<"urn:xmpp:reporting:0">>) ->
     xep0377;
 get_mod(<<"state">>, <<"jabber:iq:register">>) ->
@@ -1182,6 +1185,9 @@ get_mod(<<"reported">>, <<"jabber:x:data">>) -> xep0004;
 get_mod(<<"subject">>, <<"jabber:client">>) -> rfc6120;
 get_mod(<<"date">>, <<"jabber:iq:register">>) ->
     xep0077;
+get_mod(<<"transport">>,
+	<<"urn:xmpp:jingle:transports:ibb:1">>) ->
+    xep0261;
 get_mod(<<"auth">>,
 	<<"urn:ietf:params:xml:ns:xmpp-sasl">>) ->
     rfc6120;
@@ -1204,6 +1210,9 @@ get_mod(<<"configure">>,
 get_mod(<<"reason">>,
 	<<"http://jabber.org/protocol/muc#owner">>) ->
     xep0045;
+get_mod(<<"candidate-error">>,
+	<<"urn:xmpp:jingle:transports:s5b:1">>) ->
+    xep0260;
 get_mod(<<"password">>, <<"storage:bookmarks">>) ->
     xep0048;
 get_mod(<<"message">>, <<"jabber:component:accept">>) ->
@@ -1217,12 +1226,17 @@ get_mod(<<"reason">>,
 	<<"http://jabber.org/protocol/muc#user">>) ->
     xep0045;
 get_mod(<<"never">>, <<"urn:xmpp:mam:2">>) -> xep0313;
+get_mod(<<"proxy-error">>,
+	<<"urn:xmpp:jingle:transports:s5b:1">>) ->
+    xep0260;
 get_mod(<<"stat">>,
 	<<"http://jabber.org/protocol/stats">>) ->
     xep0039;
 get_mod(<<"always">>, <<"urn:xmpp:mam:tmp">>) ->
     xep0313;
 get_mod(<<"desc">>, <<"jabber:x:oob">>) -> xep0066;
+get_mod(<<"reason">>, <<"urn:xmpp:jingle:1">>) ->
+    xep0166;
 get_mod(<<"thread">>, <<"jabber:server">>) -> rfc6120;
 get_mod(<<"host-unknown">>,
 	<<"urn:ietf:params:xml:ns:xmpp-streams">>) ->
@@ -1273,6 +1287,8 @@ get_mod(<<"participant">>, <<"urn:xmpp:mix:0">>) ->
 get_mod(<<"delegation">>,
 	<<"urn:xmpp:delegation:1">>) ->
     xep0355;
+get_mod(<<"expired">>, <<"urn:xmpp:jingle:1">>) ->
+    xep0166;
 get_mod(<<"bad-request">>,
 	<<"urn:ietf:params:xml:ns:xmpp-stanzas">>) ->
     rfc6120;
@@ -1284,6 +1300,8 @@ get_mod(<<"sent">>, <<"urn:xmpp:carbons:2">>) ->
     xep0280;
 get_mod(<<"db:result">>, <<"jabber:server">>) ->
     xep0220;
+get_mod(<<"busy">>, <<"urn:xmpp:jingle:1">>) -> xep0166;
+get_mod(<<"text">>, <<"urn:xmpp:jingle:1">>) -> xep0166;
 get_mod(<<"group">>, <<"jabber:iq:roster">>) -> rfc6121;
 get_mod(<<"incorrect-encoding">>,
 	<<"urn:ietf:params:xml:ns:xmpp-sasl">>) ->
@@ -1299,6 +1317,9 @@ get_mod(<<"item">>,
 	<<"http://jabber.org/protocol/pubsub#event">>) ->
     xep0060;
 get_mod(<<"resumed">>, <<"urn:xmpp:sm:3">>) -> xep0198;
+get_mod(<<"activated">>,
+	<<"urn:xmpp:jingle:transports:s5b:1">>) ->
+    xep0260;
 get_mod(<<"conference">>, <<"storage:bookmarks">>) ->
     xep0048;
 get_mod(<<"registered">>, <<"jabber:iq:register">>) ->
@@ -1358,6 +1379,9 @@ get_mod(<<"mechanism">>,
 get_mod(<<"default">>,
 	<<"http://jabber.org/protocol/pubsub">>) ->
     xep0060;
+get_mod(<<"alternative-session">>,
+	<<"urn:xmpp:jingle:1">>) ->
+    xep0166;
 get_mod(<<"remote-server-timeout">>,
 	<<"urn:ietf:params:xml:ns:xmpp-stanzas">>) ->
     rfc6120;
@@ -1367,6 +1391,114 @@ get_mod(<<"invalid-from">>,
 get_mod(<<"items">>,
 	<<"http://jabber.org/protocol/pubsub">>) ->
     xep0060;
+get_mod(<<"bad-format">>,
+	<<"urn:ietf:params:xml:ns:xmpp-streams">>) ->
+    rfc6120;
+get_mod(<<"STREET">>, <<"vcard-temp">>) -> xep0054;
+get_mod(<<"status">>,
+	<<"http://jabber.org/protocol/muc#user">>) ->
+    xep0045;
+get_mod(<<"error">>, <<"jabber:server">>) -> rfc6120;
+get_mod(<<"VIDEO">>, <<"vcard-temp">>) -> xep0054;
+get_mod(<<"redirect">>,
+	<<"http://jabber.org/protocol/pubsub#event">>) ->
+    xep0060;
+get_mod(<<"destroy">>,
+	<<"http://jabber.org/protocol/muc#user">>) ->
+    xep0045;
+get_mod(<<"id">>, <<"jabber:x:event">>) -> xep0022;
+get_mod(<<"not-acceptable">>,
+	<<"urn:ietf:params:xml:ns:xmpp-stanzas">>) ->
+    rfc6120;
+get_mod(<<"SUFFIX">>, <<"vcard-temp">>) -> xep0054;
+get_mod(<<"redirect">>,
+	<<"http://jabber.org/protocol/pubsub">>) ->
+    xep0060;
+get_mod(<<"incompatible-parameters">>,
+	<<"urn:xmpp:jingle:1">>) ->
+    xep0166;
+get_mod(<<"candidate">>,
+	<<"urn:xmpp:jingle:transports:s5b:1">>) ->
+    xep0260;
+get_mod(<<"subject">>, <<"jabber:server">>) -> rfc6120;
+get_mod(<<"bad-namespace-prefix">>,
+	<<"urn:ietf:params:xml:ns:xmpp-streams">>) ->
+    rfc6120;
+get_mod(<<"EXTADD">>, <<"vcard-temp">>) -> xep0054;
+get_mod(<<"affiliation">>,
+	<<"http://jabber.org/protocol/pubsub#owner">>) ->
+    xep0060;
+get_mod(<<"fin">>, <<"urn:xmpp:mam:0">>) -> xep0313;
+get_mod(<<"enabled">>, <<"urn:xmpp:sm:2">>) -> xep0198;
+get_mod(<<"TITLE">>, <<"vcard-temp">>) -> xep0054;
+get_mod(<<"too-many-subscriptions">>,
+	<<"http://jabber.org/protocol/pubsub#errors">>) ->
+    xep0060;
+get_mod(<<"item">>,
+	<<"http://jabber.org/protocol/muc#owner">>) ->
+    xep0045;
+get_mod(<<"always">>, <<"urn:xmpp:mam:0">>) -> xep0313;
+get_mod(<<"file-too-large">>,
+	<<"urn:xmpp:http:upload:0">>) ->
+    xep0363;
+get_mod(<<"jingle">>, <<"urn:xmpp:jingle:1">>) ->
+    xep0166;
+get_mod(<<"conflict">>,
+	<<"urn:ietf:params:xml:ns:xmpp-streams">>) ->
+    rfc6120;
+get_mod(<<"X400">>, <<"vcard-temp">>) -> xep0054;
+get_mod(<<"affiliation">>,
+	<<"http://jabber.org/protocol/pubsub">>) ->
+    xep0060;
+get_mod(<<"data">>, <<"urn:xmpp:avatar:data">>) ->
+    xep0084;
+get_mod(<<"item">>,
+	<<"http://jabber.org/protocol/disco#items">>) ->
+    xep0030;
+get_mod(<<"VOICE">>, <<"vcard-temp">>) -> xep0054;
+get_mod(<<"vCard">>, <<"vcard-temp">>) -> xep0054;
+get_mod(<<"gone">>,
+	<<"http://jabber.org/protocol/chatstates">>) ->
+    xep0085;
+get_mod(<<"query">>,
+	<<"http://jabber.org/protocol/muc#owner">>) ->
+    xep0045;
+get_mod(<<"os">>, <<"jabber:iq:version">>) -> xep0092;
+get_mod(<<"feature">>,
+	<<"http://jabber.org/protocol/disco#info">>) ->
+    xep0030;
+get_mod(<<"ORGNAME">>, <<"vcard-temp">>) -> xep0054;
+get_mod(<<"NOTE">>, <<"vcard-temp">>) -> xep0054;
+get_mod(<<"REV">>, <<"vcard-temp">>) -> xep0054;
+get_mod(<<"query">>, <<"urn:xmpp:mam:1">>) -> xep0313;
+get_mod(<<"remote-server-not-found">>,
+	<<"urn:ietf:params:xml:ns:xmpp-stanzas">>) ->
+    rfc6120;
+get_mod(<<"invalid-mechanism">>,
+	<<"urn:ietf:params:xml:ns:xmpp-sasl">>) ->
+    rfc6120;
+get_mod(<<"starttls">>,
+	<<"urn:ietf:params:xml:ns:xmpp-tls">>) ->
+    rfc6120;
+get_mod(<<"unsupported-feature">>,
+	<<"urn:ietf:params:xml:ns:xmpp-streams">>) ->
+    rfc6120;
+get_mod(<<"request">>, <<"urn:xmpp:receipts">>) ->
+    xep0184;
+get_mod(<<"url">>, <<"storage:bookmarks">>) -> xep0048;
+get_mod(<<"unexpected-request">>,
+	<<"urn:ietf:params:xml:ns:xmpp-stanzas">>) ->
+    rfc6120;
+get_mod(<<"zip">>, <<"jabber:iq:register">>) -> xep0077;
+get_mod(<<"delete">>,
+	<<"http://jabber.org/protocol/pubsub#owner">>) ->
+    xep0060;
+get_mod(<<"a">>, <<"urn:xmpp:sm:2">>) -> xep0198;
+get_mod(<<"dialback">>,
+	<<"urn:xmpp:features:dialback">>) ->
+    xep0220;
+get_mod(<<"put">>, <<"urn:xmpp:http:upload">>) ->
+    xep0363;
 get_mod(Name, XMLNS) ->
     xmpp_codec_external:lookup(Name, XMLNS).
 
@@ -1377,21 +1509,17 @@ get_mod({last, _, _}) -> xep0012;
 get_mod({compression, _}) -> xep0138;
 get_mod({mam_prefs, _, _, _, _}) -> xep0313;
 get_mod({upload_file_too_large, _, _}) -> xep0363;
+get_mod({jingle_ft_description, _}) -> xep0234;
 get_mod({muc_user, _, _, _, _, _, _}) -> xep0045;
 get_mod({bytestreams, _, _, _, _, _, _}) -> xep0065;
-get_mod({muc_invite, _, _, _, _}) -> xep0045;
 get_mod({sasl_auth, _, _}) -> rfc6120;
 get_mod({vcard_logo, _, _, _}) -> xep0054;
 get_mod({ps_item, _, _, _, _, _}) -> xep0060;
-get_mod({ps_event, _, _, _, _, _, _}) -> xep0060;
 get_mod({mam_fin, _, _, _, _, _}) -> xep0313;
+get_mod({jingle_ft_error, _}) -> xep0234;
 get_mod({legacy_auth, _, _, _, _}) -> xep0078;
-get_mod({sasl_mechanisms, _}) -> rfc6120;
-get_mod({starttls, _}) -> rfc6120;
 get_mod({stream_features, _}) -> rfc6120;
 get_mod({muc_item, _, _, _, _, _, _, _}) -> xep0045;
-get_mod({stream_start, _, _, _, _, _, _, _, _}) ->
-    rfc6120;
 get_mod({block_list, _}) -> xep0191;
 get_mod({'see-other-host', _}) -> rfc6120;
 get_mod({muc_destroy, _, _, _, _}) -> xep0045;
@@ -1399,6 +1527,7 @@ get_mod({carbons_received, _}) -> xep0280;
 get_mod({carbons_sent, _}) -> xep0280;
 get_mod({hint, _}) -> xep0334;
 get_mod({origin_id, _}) -> xep0359;
+get_mod({hash_used, _}) -> xep0300;
 get_mod({disco_items, _, _, _}) -> xep0030;
 get_mod({private, _}) -> xep0049;
 get_mod({sasl_challenge, _}) -> rfc6120;
@@ -1406,6 +1535,7 @@ get_mod({compress_failure, _}) -> xep0138;
 get_mod({vcard_xupdate, _}) -> xep0153;
 get_mod({db_feature, _}) -> xep0220;
 get_mod({handshake, _}) -> xep0114;
+get_mod({ibb_close, _}) -> xep0047;
 get_mod({block_item, _, _}) -> xep0191;
 get_mod({message, _, _, _, _, _, _, _, _, _, _}) ->
     rfc6120;
@@ -1421,12 +1551,15 @@ get_mod({vcard_adr, _, _, _, _, _, _, _, _, _, _, _, _,
     xep0054;
 get_mod({xdata_option, _, _}) -> xep0004;
 get_mod({ps_unsubscribe, _, _, _}) -> xep0060;
+get_mod({muc_subscription, _, _}) -> p1_mucsub;
 get_mod({sm_resume, _, _, _}) -> xep0198;
 get_mod({push_enable, _, _, _}) -> xep0357;
+get_mod({jingle_ft_range, _, _, _}) -> xep0234;
 get_mod({vcard_geo, _, _}) -> xep0054;
 get_mod({mam_query, _, _, _, _, _, _, _, _}) -> xep0313;
 get_mod({xevent, _, _, _, _, _}) -> xep0022;
 get_mod({db_result, _, _, _, _, _}) -> xep0220;
+get_mod({jingle_content, _, _, _, _, _}) -> xep0166;
 get_mod({bookmark_conference, _, _, _, _, _}) ->
     xep0048;
 get_mod({feature_register}) -> xep0077;
@@ -1439,6 +1572,8 @@ get_mod({csi, _}) -> xep0352;
 get_mod({disco_info, _, _, _, _}) -> xep0030;
 get_mod({sm_a, _, _}) -> xep0198;
 get_mod({oob_x, _, _, _}) -> xep0066;
+get_mod({jingle_s5b_transport, _, _, _, _, _, _, _}) ->
+    xep0260;
 get_mod({privacy_query, _, _, _}) -> xep0016;
 get_mod({block, _}) -> xep0191;
 get_mod({vcard_label, _, _, _, _, _, _, _, _}) ->
@@ -1448,6 +1583,7 @@ get_mod({ps_error, _, _}) -> xep0060;
 get_mod({delay, _, _, _}) -> xep0203;
 get_mod({muc_actor, _, _}) -> xep0045;
 get_mod({nick, _}) -> xep0172;
+get_mod({jingle, _, _, _, _, _, _, _}) -> xep0166;
 get_mod({stats, _, _}) -> xep0039;
 get_mod({vcard_temp, _, _, _, _, _, _, _, _, _, _, _, _,
 	 _, _, _, _, _, _, _, _, _, _, _, _, _, _, _, _, _}) ->
@@ -1460,7 +1596,6 @@ get_mod({avatar_info, _, _, _, _, _, _}) -> xep0084;
 get_mod({privacy_list, _, _}) -> xep0016;
 get_mod({report, _, _}) -> xep0377;
 get_mod({message_thread, _, _}) -> rfc6120;
-get_mod({text, _, _}) -> rfc6120;
 get_mod({shim, _}) -> xep0131;
 get_mod({mam_archived, _, _}) -> xep0313;
 get_mod({forwarded, _, _}) -> xep0297;
@@ -1468,6 +1603,8 @@ get_mod({feature_sm, _}) -> xep0198;
 get_mod({mix_participant, _, _}) -> xep0369;
 get_mod({stanza_id, _, _}) -> xep0359;
 get_mod({delegated, _, _}) -> xep0355;
+get_mod({text, _, _}) -> xep0234;
+get_mod({jingle_ft_received, _, _}) -> xep0234;
 get_mod({bookmark_storage, _, _}) -> xep0048;
 get_mod({sasl_failure, _, _}) -> rfc6120;
 get_mod({xmpp_session, _}) -> rfc3921;
@@ -1487,11 +1624,13 @@ get_mod({pubsub_owner, _, _, _, _, _, _}) -> xep0060;
 get_mod({mam_result, _, _, _, _}) -> xep0313;
 get_mod({sm_failed, _, _, _, _}) -> xep0198;
 get_mod({upload_request, _, _, _, _}) -> xep0363;
+get_mod({jingle_ft_checksum, _, _, _}) -> xep0234;
 get_mod({version, _, _, _}) -> xep0092;
 get_mod({vcard_org, _, _}) -> xep0054;
 get_mod({ps_items, _, _, _, _, _, _}) -> xep0060;
 get_mod({muc_subscribe, _, _, _, _}) -> p1_mucsub;
 get_mod({feature_csi}) -> xep0352;
+get_mod({ibb_open, _, _, _}) -> xep0047;
 get_mod({roster_item, _, _, _, _, _}) -> rfc6121;
 get_mod({vcard_tel, _, _, _, _, _, _, _, _, _, _, _, _,
 	 _, _}) ->
@@ -1501,12 +1640,16 @@ get_mod({ps_publish, _, _}) -> xep0060;
 get_mod({search_item, _, _, _, _, _}) -> xep0055;
 get_mod({xcaptcha, _}) -> xep0158;
 get_mod({avatar_data, _}) -> xep0084;
+get_mod({hash, _, _}) -> xep0300;
 get_mod({roster_query, _, _}) -> rfc6121;
 get_mod({vcard_key, _, _}) -> xep0054;
 get_mod({sm_r, _}) -> xep0198;
 get_mod({media_uri, _, _}) -> xep0221;
 get_mod({upload_slot_0, _, _, _}) -> xep0363;
 get_mod({delegation_query, _, _}) -> xep0355;
+get_mod({jingle_error, _}) -> xep0166;
+get_mod({jingle_s5b_candidate, _, _, _, _, _, _}) ->
+    xep0260;
 get_mod({sasl_success, _}) -> rfc6120;
 get_mod({compress, _}) -> xep0138;
 get_mod({xdata_field, _, _, _, _, _, _, _, _}) ->
@@ -1516,10 +1659,13 @@ get_mod({addresses, _}) -> xep0033;
 get_mod({adhoc_command, _, _, _, _, _, _, _, _}) ->
     xep0050;
 get_mod({media, _, _, _}) -> xep0221;
+get_mod({ibb_data, _, _, _}) -> xep0047;
 get_mod({identity, _, _, _, _}) -> xep0030;
 get_mod({redirect, _}) -> rfc6120;
 get_mod({muc_history, _, _, _, _}) -> xep0045;
 get_mod({muc_owner, _, _, _}) -> xep0045;
+get_mod({jingle_ft_file, _, _, _, _, _, _, _, _}) ->
+    xep0234;
 get_mod({bookmark_url, _, _}) -> xep0048;
 get_mod({gone, _}) -> rfc6120;
 get_mod({sasl_response, _}) -> rfc6120;
@@ -1527,10 +1673,12 @@ get_mod({chatstate, _}) -> xep0085;
 get_mod({muc_unique, _}) -> xep0045;
 get_mod({receipt_response, _}) -> xep0184;
 get_mod({sic, _, _, _}) -> xep0279;
+get_mod({idle, _}) -> xep0319;
 get_mod({sm_resumed, _, _, _}) -> xep0198;
 get_mod({offline_item, _, _}) -> xep0013;
 get_mod({db_verify, _, _, _, _, _, _}) -> xep0220;
 get_mod({upload_slot, _, _, _}) -> xep0363;
+get_mod({jingle_ibb_transport, _, _, _}) -> xep0261;
 get_mod({muc_decline, _, _, _}) -> xep0045;
 get_mod({sm_enable, _, _, _}) -> xep0198;
 get_mod({offline, _, _, _}) -> xep0013;
@@ -1568,4 +1716,11 @@ get_mod({expire, _, _}) -> xep0023;
 get_mod({privilege, _, _}) -> xep0356;
 get_mod({stanza_error, _, _, _, _, _, _}) -> rfc6120;
 get_mod({avatar_pointer, _, _, _, _, _, _}) -> xep0084;
+get_mod({muc_invite, _, _, _, _}) -> xep0045;
+get_mod({jingle_reason, _, _, _}) -> xep0166;
+get_mod({ps_event, _, _, _, _, _, _}) -> xep0060;
+get_mod({sasl_mechanisms, _}) -> rfc6120;
+get_mod({starttls, _}) -> rfc6120;
+get_mod({stream_start, _, _, _, _, _, _, _, _}) ->
+    rfc6120;
 get_mod(Record) -> xmpp_codec_external:lookup(Record).
